Description Usage Arguments Details Value References See Also Examples
View source: R/descriptive_stats.R
prec_rate returns the sample size or the precision for the provided
rate
1 2 3 |
r |
rate or rate ratio. |
x |
number of events |
conf.width |
precision (the full width of the conficende interval) |
conf.level |
confidence level |
method |
The method to use to calculate precision. Exactly one method may be provided. Methods can be abbreviated. |
tol |
numerical tolerance used in root finding, the default providing (at least) four significant digits |
Exactly one of the parameters r, conf.width must be passed as NULL,
and that parameter is determined from the other.
The score, variance stabilizing (vs), exact, and
wald method are implemented to calculate the rate and the precision.
For few events x (<5), the exact method is recommended.
If more than one method is specified or the method is miss-specified, the 'score' method will be used.
uniroot is used to solve n for the score and
exact method. Agresti-coull can be abbreviated by ac.
Object of class "presize", a list of arguments (including the computed one) augmented with method and note elements.
Barker, L. (2002) A Comparison of Nine Confidence Intervals for a Poisson Parameter When the Expected Number of Events is ≤ 5, The American Statistician, 56:2, 85-89, DOI: 10.1198/000313002317572736
1 2 3 4 5 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.